% Auto-generated chapter 28 for bukhari
% Hadiths in this chapter: 46

\hadithdefcmd{bukhari}{1821}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، قَالَ انْطَلَقَ أَبِي عَامَ الْحُدَيْبِيَةِ فَأَحْرَمَ أَصْحَابُهُ، وَلَمْ يُحْرِمْ، وَحُدِّثَ النَّبِيُّ صلى الله عليه وسلم أَنَّ عَدُوًّا يَغْزُوهُ، فَانْطَلَقَ النَّبِيُّ صلى الله عليه وسلم، فَبَيْنَمَا أَنَا مَعَ أَصْحَابِهِ يَضْحَكُ بَعْضُهُمْ إِلَى بَعْضٍ، فَنَظَرْتُ فَإِذَا أَنَا بِحِمَارِ وَحْشٍ، فَحَمَلْتُ عَلَيْهِ، فَطَعَنْتُهُ، فَأَثْبَتُّهُ، وَاسْتَعَنْتُ بِهِمْ، فَأَبَوْا أَنْ يُعِينُونِي، فَأَكَلْنَا مِنْ لَحْمِهِ، وَخَشِينَا أَنْ نُقْتَطَعَ، فَطَلَبْتُ النَّبِيَّ صلى الله عليه وسلم أَرْفَعُ فَرَسِي شَأْوًا، وَأَسِيرُ شَأْوًا، فَلَقِيتُ رَجُلاً مِنْ بَنِي غِفَارٍ فِي جَوْفِ اللَّيْلِ قُلْتُ أَيْنَ تَرَكْتَ النَّبِيَّ صلى الله عليه وسلم قَالَ تَرَكْتُهُ بِتَعْهِنَ، وَهُوَ قَائِلٌ السُّقْيَا‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَهْلَكَ يَقْرَءُونَ عَلَيْكَ السَّلاَمَ وَرَحْمَةَ اللَّهِ، إِنَّهُمْ قَدْ خَشُوا أَنْ يُقْتَطَعُوا دُونَكَ، فَانْتَظِرْهُمْ قُلْتُ يَا رَسُولَ اللَّهِ أَصَبْتُ حِمَارَ وَحْشٍ، وَعِنْدِي مِنْهُ فَاضِلَةٌ‏.‏ فَقَالَ لِلْقَوْمِ ‏ "‏ كُلُوا ‏"‏ وَهُمْ مُحْرِمُونَ‏.‏\hadithno{1821}\hadithtrans{Narrated `Abdullah bin Abu Qatada:My father set out (for Mecca) in the year of Al-Hudaibiya, and his companions assumed Ihram, but he did not. At that time the Prophet (ﷺ) was informed that an enemy wanted to attack him, so the Prophet (ﷺ) proceeded onwards. While my father was among his companions, some of them laughed among themselves. (My father said), "I looked up and saw an onager. I attacked, stabbed and caught it. I then sought my companions' help but they refused to help me. (Later) we all ate its meat. We were afraid that we might be left behind (separated) from the Prophet (ﷺ) so I went in search of the Prophet (ﷺ) and made my horse to run at a galloping speed at times and let it go slow at an ordinary speed at other times till I met a man from the tribe of Bani Ghifar at midnight. I asked him, "Where did you leave the Prophet (ﷺ) ?" He replied, "I left him at Ta'hin and he had the intention of having the midday rest at As-Suqya. I followed the trace and joined the Prophet (ﷺ) and said, 'O Allah's Messenger (ﷺ)! Your people (companions) send you their compliments, and (ask for) Allah's Blessings upon you. They are afraid lest they may be left behind; so please wait for them.' I added, 'O Allah's Messenger (ﷺ)! I hunted an onager and some of its meat is with me. The Prophet (ﷺ) told the people to eat it though all of them were in the state of Ihram}}
\hadithdefcmd{bukhari}{1822}{حَدَّثَنَا سَعِيدُ بْنُ الرَّبِيعِ، حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، أَنَّ أَبَاهُ، حَدَّثَهُ قَالَ انْطَلَقْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم عَامَ الْحُدَيْبِيَةِ فَأَحْرَمَ أَصْحَابُهُ، وَلَمْ أُحْرِمْ، فَأُنْبِئْنَا بِعَدُوٍّ بِغَيْقَةَ فَتَوَجَّهْنَا نَحْوَهُمْ، فَبَصُرَ أَصْحَابِي بِحِمَارِ وَحْشٍ، فَجَعَلَ بَعْضُهُمْ يَضْحَكُ إِلَى بَعْضٍ، فَنَظَرْتُ فَرَأَيْتُهُ فَحَمَلْتُ عَلَيْهِ الْفَرَسَ، فَطَعَنْتُهُ، فَأَثْبَتُّهُ، فَاسْتَعَنْتُهُمْ، فَأَبَوْا أَنْ يُعِينُونِي، فَأَكَلْنَا مِنْهُ، ثُمَّ لَحِقْتُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَخَشِينَا أَنْ نُقْتَطَعَ، أَرْفَعُ فَرَسِي شَأْوًا، وَأَسِيرُ عَلَيْهِ شَأْوًا، فَلَقِيتُ رَجُلاً مِنْ بَنِي غِفَارٍ فِي جَوْفِ اللَّيْلِ فَقُلْتُ أَيْنَ تَرَكْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ تَرَكْتُهُ بِتَعْهِنَ وَهُوَ قَائِلٌ السُّقْيَا‏.‏ فَلَحِقْتُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى أَتَيْتُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ، إِنَّ أَصْحَابَكَ أَرْسَلُوا يَقْرَءُونَ عَلَيْكَ السَّلاَمَ وَرَحْمَةَ اللَّهِ وَبَرَكَاتِهِ، وَإِنَّهُمْ قَدْ خَشُوا أَنْ يَقْتَطِعَهُمُ الْعُدُوُّ دُونَكَ، فَانْظُرْهُمْ، فَفَعَلَ فَقُلْتُ يَا رَسُولَ اللَّهِ، إِنَّا اصَّدْنَا حِمَارَ وَحْشٍ، وَإِنَّ عِنْدَنَا فَاضِلَةً‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَصْحَابِهِ ‏ "‏ كُلُوا ‏"‏‏.‏ وَهُمْ مُحْرِمُونَ‏.‏\hadithno{1822}\hadithtrans{Narrated `Abdullah bin Abu Qatada:That his father said "We proceeded with the Prophet (ﷺ) in the year of Al-Hudaibiya and his companions assumed Ihram but I did not. We were informed that some enemies were at Ghaiqa and so we went on towards them. My companions saw an onager and some of them started laughing among themselves. I looked and saw it. I chased it with my horse and stabbed and caught it. I wanted some help from my companions but they refused. (I slaughtered it all alone). We all ate from it (i.e. its meat). Then I followed Allah's Messenger (ﷺ) lest we should be left behind. At times I urged my horse to run at a galloping speed and at other times at an ordinary slow speed. On the way I met a man from the tribe of Bani Ghifar at midnight. I asked him where he had left Allah's Messenger (ﷺ) . The man replied that he had left the Prophet (ﷺ) at a place called Ta'hin and he had the intention of having the midday rest at As-Suqya. So, I followed Allah's Messenger (ﷺ) till I reached him and said, "O Allah's Messenger (ﷺ)! I have been sent by my companions who send you their greetings and compliments and ask for Allah's Mercy and Blessings upon you. They were afraid lest the enemy might intervene between you and them; so please wait for them." So he did. Then I said, "O Allah's Messenger (ﷺ)! We have hunted an onager and have some of it (i.e. its meat) left over." Allah's Messenger (ﷺ) told his companions to eat the meat although all of them were in a state of Ihram}}
\hadithdefcmd{bukhari}{1823}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا صَالِحُ بْنُ كَيْسَانَ، عَنْ أَبِي مُحَمَّدٍ، نَافِعٍ مَوْلَى أَبِي قَتَادَةَ سَمِعَ أَبَا قَتَادَةَ ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم بِالْقَاحَةِ مِنَ الْمَدِينَةِ عَلَى ثَلاَثٍ ح‏.‏ وَحَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ حَدَّثَنَا سُفْيَانُ حَدَّثَنَا صَالِحُ بْنُ كَيْسَانَ عَنْ أَبِي مُحَمَّدٍ عَنْ أَبِي قَتَادَةَ ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم بِالْقَاحَةِ، وَمِنَّا الْمُحْرِمُ، وَمِنَّا غَيْرُ الْمُحْرِمِ، فَرَأَيْتُ أَصْحَابِي يَتَرَاءَوْنَ شَيْئًا فَنَظَرْتُ، فَإِذَا حِمَارُ وَحْشٍ ـ يَعْنِي وَقَعَ سَوْطُهُ ـ فَقَالُوا لاَ نُعِينُكَ عَلَيْهِ بِشَىْءٍ، إِنَّا مُحْرِمُونَ‏.‏ فَتَنَاوَلْتُهُ فَأَخَذْتُهُ، ثُمَّ أَتَيْتُ الْحِمَارَ مِنْ وَرَاءِ أَكَمَةٍ، فَعَقَرْتُهُ، فَأَتَيْتُ بِهِ أَصْحَابِي، فَقَالَ بَعْضُهُمْ كُلُوا‏.‏ وَقَالَ بَعْضُهُمْ لاَ تَأْكُلُوا‏.‏ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَهُوَ أَمَامَنَا، فَسَأَلْتُهُ فَقَالَ ‏ "‏ كُلُوهُ حَلاَلٌ ‏"‏‏.‏ قَالَ لَنَا عَمْرٌو اذْهَبُوا إِلَى صَالِحٍ فَسَلُوهُ عَنْ هَذَا وَغَيْرِهِ، وَقَدِمَ عَلَيْنَا هَا هُنَا‏.‏\hadithno{1823}\hadithtrans{Narrated Abu Qatada:We were in the company of the Prophet (ﷺ) at a place called Al-Qaha (which is at a distance of three stages of journey from Medina). Abu Qatada narrated through another group of narrators: We were in the company of the Prophet (ﷺ) at a place called Al-Qaha and some of us had assumed Ihram while the others had not. I noticed that some of my companions were watching something, so I looked up and saw an onager. (I rode my horse and took the spear and whip) but my whip fell down (and I asked them to pick it up for me) but they said, "We will not help you by any means as we are in a state of Ihram." So, I picked up the whip myself and attacked the onager from behind a hillock and slaughtered it and brought it to my companions. Some of them said, "Eat it." While some others said, "Do not eat it." So, I went to the Prophet (ﷺ) who was ahead of us and asked him about it, He replied, "Eat it as it is Halal (i.e. it is legal to eat it)}}
\hadithdefcmd{bukhari}{1824}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا عُثْمَانُ ـ هُوَ ابْنُ مَوْهَبٍ ـ قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَبِي قَتَادَةَ، أَنَّ أَبَاهُ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ حَاجًّا، فَخَرَجُوا مَعَهُ فَصَرَفَ طَائِفَةً مِنْهُمْ، فِيهِمْ أَبُو قَتَادَةَ فَقَالَ خُذُوا سَاحِلَ الْبَحْرِ حَتَّى نَلْتَقِيَ‏.‏ فَأَخَذُوا سَاحِلَ الْبَحْرِ، فَلَمَّا انْصَرَفُوا أَحْرَمُوا كُلُّهُمْ إِلاَّ أَبُو قَتَادَةَ لَمْ يُحْرِمْ، فَبَيْنَمَا هُمْ يَسِيرُونَ إِذْ رَأَوْا حُمُرَ وَحْشٍ، فَحَمَلَ أَبُو قَتَادَةَ عَلَى الْحُمُرِ، فَعَقَرَ مِنْهَا أَتَانًا، فَنَزَلُوا فَأَكَلُوا مِنْ لَحْمِهَا، وَقَالُوا أَنَأْكُلُ لَحْمَ صَيْدٍ وَنَحْنُ مُحْرِمُونَ فَحَمَلْنَا مَا بَقِيَ مِنْ لَحْمِ الأَتَانِ، فَلَمَّا أَتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم قَالُوا يَا رَسُولَ اللَّهِ، إِنَّا كُنَّا أَحْرَمْنَا وَقَدْ كَانَ أَبُو قَتَادَةَ لَمْ يُحْرِمْ، فَرَأَيْنَا حُمُرَ وَحْشٍ فَحَمَلَ عَلَيْهَا أَبُو قَتَادَةَ، فَعَقَرَ مِنْهَا أَتَانًا، فَنَزَلْنَا فَأَكَلْنَا مِنْ لَحْمِهَا ثُمَّ قُلْنَا أَنَأْكُلُ لَحْمَ صَيْدٍ وَنَحْنُ مُحْرِمُونَ فَحَمَلْنَا مَا بَقِيَ مِنْ لَحْمِهَا‏.‏ قَالَ ‏"‏ مِنْكُمْ أَحَدٌ أَمَرَهُ أَنْ يَحْمِلَ عَلَيْهَا، أَوْ أَشَارَ إِلَيْهَا ‏"‏‏.‏ قَالُوا لاَ‏.‏ قَالَ ‏"‏ فَكُلُوا مَا بَقِيَ مِنْ لَحْمِهَا ‏"‏‏.‏\hadithno{1824}\hadithtrans{Narrated `Abdullah bin Abu Qatada:That his father had told him that Allah's Messenger (ﷺ) set out for Hajj and so did his companions. He sent a batch of his companions by another route and Abu Qatada was one of them. The Prophet (ﷺ) said to them, "Proceed along the seashore till we meet all together." So, they took the route of the seashore, and when they started all of them assumed Ihram except Abu Qatada. While they were proceeding on, his companions saw a group of onagers. Abu Qatada chased the onagers and attacked and wounded a sheonager. They got down and ate some of its meat and said to each other: "How do we eat the meat of the game while we are in a state of Ihram?" So, we (they) carried the rest of the she-onager's meat, and when they met Allah's Messenger (ﷺ) they asked, saying, "O Allah's Messenger (ﷺ)! We assumed Ihram with the exception of Abu Qatada and we saw (a group) of onagers. Abu Qatada attacked them and wounded a she-onager from them. Then we got down and ate from its meat. Later, we said, (to each other), 'How do we eat the meat of the game and we are in a state of Ihram?' So, we carried the rest of its meat. The Prophet asked, "Did anyone of you order Abu Qatada to attack it or point at it?" They replied in the negative. He said, "Then eat what is left of its meat}}
\hadithdefcmd{bukhari}{1825}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ الصَّعْبِ بْنِ جَثَّامَةَ اللَّيْثِيِّ، أَنَّهُ أَهْدَى لِرَسُولِ اللَّهِ صلى الله عليه وسلم حِمَارًا وَحْشِيًّا، وَهْوَ بِالأَبْوَاءِ أَوْ بِوَدَّانَ فَرَدَّهُ عَلَيْهِ، فَلَمَّا رَأَى مَا فِي وَجْهِهِ قَالَ ‏ "‏ إِنَّا لَمْ نَرُدَّهُ عَلَيْكَ إِلاَّ أَنَّا حُرُمٌ ‏"‏‏.‏\hadithno{1825}\hadithtrans{Narrated `Abdullah bin `Abbas:From As-Sa'b bin Jath-thama Al-Laithi that the latter presented an onager to Allah's Messenger (ﷺ) while he was at Al-Abwa' or at Waddan, and he refused it. On noticing the signs of some unpleasant feeling of disappointment on his (As-Sab's) face, the Prophet (ﷺ) said to him, "I have only returned it because I am Muhrim}}
\hadithdefcmd{bukhari}{1826}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ لَيْسَ عَلَى الْمُحْرِمِ فِي قَتْلِهِنَّ جُنَاحٌ ‏"‏‏.‏ وَعَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ‏.‏\hadithno{1826}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "It is not sinful of a Muhrim to kill five kinds of animals}}
\hadithdefcmd{bukhari}{1827}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ زَيْدِ بْنِ جُبَيْرٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ حَدَّثَتْنِي إِحْدَى، نِسْوَةِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ يَقْتُلُ الْمُحْرِمُ ‏"‏‏.‏\hadithno{1827}\hadithtrans{One of the wives of the Prophet (ﷺ) narrated:The Prophet (ﷺ) said, "A Muhrim can kill (five kinds of animals)}}
\hadithdefcmd{bukhari}{1828}{حَدَّثَنَا أَصْبَغُ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ ـ رضى الله عنهما ـ قَالَتْ حَفْصَةُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ لاَ حَرَجَ عَلَى مَنْ قَتَلَهُنَّ الْغُرَابُ وَالْحِدَأَةُ وَالْفَأْرَةُ وَالْعَقْرَبُ وَالْكَلْبُ الْعَقُورُ ‏"‏‏.‏\hadithno{1828}\hadithtrans{Narrated Hafsa:Allah's Messenger (ﷺ) said, "It is not sinful (of a Muhrim) to kill five kinds of animals, namely: the crow, the kite, the mouse, the scorpion and the rabid dog}}
\hadithdefcmd{bukhari}{1829}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ كُلُّهُنَّ فَاسِقٌ، يَقْتُلُهُنَّ فِي الْحَرَمِ الْغُرَابُ وَالْحِدَأَةُ وَالْعَقْرَبُ وَالْفَأْرَةُ وَالْكَلْبُ الْعَقُورُ ‏"‏‏.‏\hadithno{1829}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) said, "Five kinds of animals are harmful and could be killed in the Haram (Sanctuary). These are: the crow, the kite, the scorpion, the mouse and the rabid dog}}
\hadithdefcmd{bukhari}{1830}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ بَيْنَمَا نَحْنُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي غَارٍ بِمِنًى، إِذْ نَزَلَ عَلَيْهِ ‏\{‏وَالْمُرْسَلاَتِ‏\}‏ وَإِنَّهُ لَيَتْلُوهَا، وَإِنِّي لأَتَلَقَّاهَا مِنْ فِيهِ، وَإِنَّ فَاهُ لَرَطْبٌ بِهَا، إِذْ وَثَبَتْ عَلَيْنَا حَيَّةٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اقْتُلُوهَا ‏"‏‏.‏ فَابْتَدَرْنَاهَا، فَذَهَبَتْ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وُقِيَتْ شَرَّكُمْ كَمَا وُقِيتُمْ شَرَّهَا ‏"‏‏.‏\hadithno{1830}\hadithtrans{Narrated `Abdullah:While we were in the company of the Prophet (ﷺ) in a cave at Mina, when Surat-wal-Mursalat were revealed and he recited it and I heard it (directly) from his mouth as soon as he recited its revelation. Suddenly a snake sprang at us and the Prophet (ﷺ) said (ordered us): "Kill it." We ran to kill it but it escaped quickly. The Prophet (ﷺ) said, "It has escaped your evil and you too have escaped its evil}}
\hadithdefcmd{bukhari}{1831}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِلْوَزَغِ ‏ "‏ فُوَيْسِقٌ ‏"‏‏.‏ وَلَمْ أَسْمَعْهُ أَمَرَ بِقَتْلِهِ‏.‏\hadithno{1831}\hadithtrans{Narrated `Aisha the wife of the Prophet:Allah's Messenger (ﷺ) called the salamander a bad animal, but I did not hear him ordering it to be killed}}
\hadithdefcmd{bukhari}{1832}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي شُرَيْحٍ الْعَدَوِيِّ، أَنَّهُ قَالَ لِعَمْرِو بْنِ سَعِيدٍ، وَهُوَ يَبْعَثُ الْبُعُوثَ إِلَى مَكَّةَ ائْذَنْ لِي أَيُّهَا الأَمِيرُ أُحَدِّثْكَ قَوْلاً قَامَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلْغَدِ مِنْ يَوْمِ الْفَتْحِ، فَسَمِعَتْهُ أُذُنَاىَ، وَوَعَاهُ قَلْبِي، وَأَبْصَرَتْهُ عَيْنَاىَ حِينَ تَكَلَّمَ بِهِ، إِنَّهُ حَمِدَ اللَّهَ، وَأَثْنَى عَلَيْهِ، ثُمَّ قَالَ ‏ "‏ إِنَّ مَكَّةَ حَرَّمَهَا اللَّهُ وَلَمْ يُحَرِّمْهَا النَّاسُ، فَلاَ يَحِلُّ لاِمْرِئٍ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ يَسْفِكَ بِهَا دَمًا وَلاَ يَعْضُدَ بِهَا شَجَرَةً، فَإِنْ أَحَدٌ تَرَخَّصَ لِقِتَالِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُولُوا لَهُ إِنَّ اللَّهَ أَذِنَ لِرَسُولِهِ صلى الله عليه وسلم وَلَمْ يَأْذَنْ لَكُمْ، وَإِنَّمَا أَذِنَ لِي سَاعَةً مِنْ نَهَارٍ، وَقَدْ عَادَتْ حُرْمَتُهَا الْيَوْمَ كَحُرْمَتِهَا بِالأَمْسِ، وَلْيُبَلِّغِ الشَّاهِدُ الْغَائِبَ ‏"‏‏.‏ فَقِيلَ لأَبِي شُرَيْحٍ مَا قَالَ لَكَ عَمْرٌو قَالَ أَنَا أَعْلَمُ بِذَلِكَ مِنْكَ يَا أَبَا شُرَيْحٍ، إِنَّ الْحَرَمَ لاَ يُعِيذُ عَاصِيًا، وَلاَ فَارًّا بِدَمٍ، وَلاَ فَارًّا بِخَرْبَةٍ‏.‏ خَرْبَةٌ بَلِيَّةٌ‏.‏\hadithno{1832}\hadithtrans{Narrated Sa`id bin Abu Sa`id Al-Maqburi:Abu Shuraih, Al-`Adawi said that he had said to `Amr bin Sa`id when he was sending the troops to Mecca (to fight `Abdullah bin Az-Zubair), "O Chief! Allow me to tell you what Allah's Messenger (ﷺ) said on the day following the Conquest of Mecca. My ears heard that and my heart understood it thoroughly and I saw with my own eyes the Prophet (ﷺ) when he, after Glorifying and Praising Allah, started saying, 'Allah, not the people, made Mecca a sanctuary, so anybody who has belief in Allah and the Last Day should neither shed blood in it, nor should he cut down its trees. If anybody tells (argues) that fighting in it is permissible on the basis that Allah's Messenger (ﷺ) did fight in Mecca, say to him, 'Allah allowed His Apostle and did not allow you.' "Allah allowed me only for a few hours on that day (of the conquest) and today its sanctity is valid as it was before. So, those who are present should inform those who are absent (concerning this fact." Abu Shuraih was asked, "What did `Amr reply?" He said, (`Amr said) 'O Abu Shuraih! I know better than you in this respect Mecca does not give protection to a sinner, a murderer or a thief}}
\hadithdefcmd{bukhari}{1833}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ اللَّهَ حَرَّمَ مَكَّةَ، فَلَمْ تَحِلَّ لأَحَدٍ قَبْلِي، وَلاَ تَحِلُّ لأَحَدٍ بَعْدِي، وَإِنَّمَا أُحِلَّتْ لِي سَاعَةً مِنْ نَهَارٍ، لاَ يُخْتَلَى خَلاَهَا، وَلاَ يُعْضَدُ شَجَرُهَا، وَلاَ يُنَفَّرُ صَيْدُهَا، وَلاَ تُلْتَقَطُ لُقَطَتُهَا إِلاَّ لِمُعَرِّفٍ ‏"‏‏.‏ وَقَالَ الْعَبَّاسُ يَا رَسُولَ اللَّهِ‏.‏ إِلاَّ الإِذْخِرَ لِصَاغَتِنَا وَقُبُورِنَا‏.‏ فَقَالَ ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏‏.‏ وَعَنْ خَالِدٍ عَنْ عِكْرِمَةَ قَالَ هَلْ تَدْرِي مَا لاَ يُنَفَّرُ صَيْدُهَا هُوَ أَنْ يُنَحِّيَهُ مِنَ الظِّلِّ، يَنْزِلُ مَكَانَهُ‏.‏\hadithno{1833}\hadithtrans{Narrated Ibn `Abbas:"The Prophet (ﷺ) said, 'Allah has made Mecca, a sanctuary, so it was a sanctuary before me and will continue to be a sanctuary after me. It was made legal for me (i.e. I was allowed to fight in it) for a few hours of a day. It is not allowed to uproot its shrubs or to cut its trees, or to chase (or disturb) its game, or to pick up its luqata (fallen things) except by a person who would announce that (what he has found) publicly.' Al-`Abbas said, 'O Allah's Messenger (ﷺ)! Except Al-Idhkhir (a kind of grass) (for it is used) by our goldsmiths and for our graves.' The Prophet (ﷺ) then said, 'Except Al-Idhkhir.' " `Ikrima said, 'Do you know what "chasing or disturbing" the game means? It means driving it out of the shade to occupy its place}}
\hadithdefcmd{bukhari}{1834}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ افْتَتَحَ مَكَّةَ ‏"‏ لاَ هِجْرَةَ وَلَكِنْ جِهَادٌ وَنِيَّةٌ، وَإِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا، فَإِنَّ هَذَا بَلَدٌ حَرَّمَ اللَّهُ يَوْمَ خَلَقَ السَّمَوَاتِ وَالأَرْضَ، وَهُوَ حَرَامٌ بِحُرْمَةِ اللَّهِ إِلَى يَوْمِ الْقِيَامَةِ، وَإِنَّهُ لَمْ يَحِلَّ الْقِتَالُ فِيهِ لأَحَدٍ قَبْلِي، وَلَمْ يَحِلَّ لِي إِلاَّ سَاعَةً مِنْ نَهَارٍ، فَهُوَ حَرَامٌ بِحُرْمَةِ اللَّهِ إِلَى يَوْمِ الْقِيَامَةِ، لاَ يُعْضَدُ شَوْكُهُ، وَلاَ يُنَفَّرُ صَيْدُهُ، وَلاَ يَلْتَقِطُ لُقَطَتَهُ إِلاَّ مَنْ عَرَّفَهَا، وَلاَ يُخْتَلَى خَلاَهَا ‏"‏‏.‏ قَالَ الْعَبَّاسُ يَا رَسُولَ اللَّهِ‏.‏ إِلاَّ الإِذْخِرَ، فَإِنَّهُ لِقَيْنِهِمْ وَلِبُيُوتِهِمْ‏.‏ قَالَ قَالَ ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏‏.‏\hadithno{1834}\hadithtrans{Narrated Ibn `Abbas:On the day of the conquest of Mecca, the Prophet (ﷺ) said, "There is no more emigration (from Mecca) but Jihad and intentions, and whenever you are called for Jihad, you should go immediately. No doubt, Allah has made this place (Mecca) a sanctuary since the creation of the heavens and the earth and will remain a sanctuary till the Day of Resurrection as Allah has ordained its sanctity. Fighting was not permissible in it for anyone before me, and even for me it was allowed only for a portion of a day. So, it is a sanctuary with Allah's sanctity till the Day of Resurrection. Its thorns should not be uprooted and its game should not be chased; and its luqata (fallen things) should not be picked up except by one who would announce that publicly, and its vegetation (grass etc.) should not be cut." Al-`Abbas said, "O Allah's Messenger (ﷺ)! Except Al-Idhkhir, (for it is used by their blacksmiths and for their domestic purposes)." So, the Prophet (ﷺ) said, "Except Al-Idhkhir}}
\hadithdefcmd{bukhari}{1835}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ قَالَ عَمْرٌو أَوَّلُ شَىْءٍ سَمِعْتُ عَطَاءً، يَقُولُ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ احْتَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ‏.‏ ثُمَّ سَمِعْتُهُ يَقُولُ حَدَّثَنِي طَاوُسٌ عَنِ ابْنِ عَبَّاسٍ فَقُلْتُ لَعَلَّهُ سَمِعَهُ مِنْهُمَا‏.‏\hadithno{1835}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) was cupped while he was in a state of Ihram}}
\hadithdefcmd{bukhari}{1836}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ عَلْقَمَةَ بْنِ أَبِي عَلْقَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنِ ابْنِ بُحَيْنَةَ ـ رضى الله عنه ـ قَالَ احْتَجَمَ النَّبِيُّ صلى الله عليه وسلم وَهْوَ مُحْرِمٌ بِلَحْىِ جَمَلٍ فِي وَسَطِ رَأْسِهِ‏.‏\hadithno{1836}\hadithtrans{Narrated Ibn Buhaina:The Prophet, while in the state of Ihram, was cupped at the middle of his head at Liha-Jamal}}
\hadithdefcmd{bukhari}{1837}{حَدَّثَنَا أَبُو الْمُغِيرَةِ عَبْدُ الْقُدُّوسِ بْنُ الْحَجَّاجِ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي عَطَاءُ بْنُ أَبِي رَبَاحٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُوَ مُحْرِمٌ‏.‏\hadithno{1837}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) married Maimuna while he was in the state of Ihram, (only the ceremonies of marriage were held)}}
\hadithdefcmd{bukhari}{1838}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا نَافِعٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ مَاذَا تَأْمُرُنَا أَنْ نَلْبَسَ مِنَ الثِّيَابِ فِي الإِحْرَامِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَلْبَسُوا الْقَمِيصَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْعَمَائِمَ، وَلاَ الْبَرَانِسَ إِلاَّ أَنْ يَكُونَ أَحَدٌ لَيْسَتْ لَهُ نَعْلاَنِ، فَلْيَلْبَسِ الْخُفَّيْنِ، وَلْيَقْطَعْ أَسْفَلَ مِنَ الْكَعْبَيْنِ، وَلاَ تَلْبَسُوا شَيْئًا مَسَّهُ زَعْفَرَانٌ، وَلاَ الْوَرْسُ، وَلاَ تَنْتَقِبِ الْمَرْأَةُ الْمُحْرِمَةُ وَلاَ تَلْبَسِ الْقُفَّازَيْنِ ‏"‏‏.‏ تَابَعَهُ مُوسَى بْنُ عُقْبَةَ وَإِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ بْنِ عُقْبَةَ وَجُوَيْرِيَةُ وَابْنُ إِسْحَاقَ فِي النِّقَابِ وَالْقُفَّازَيْنِ‏.‏ وَقَالَ عُبَيْدُ اللَّهِ وَلاَ وَرْسٌ وَكَانَ يَقُولُ لاَ تَتَنَقَّبِ الْمُحْرِمَةُ، وَلاَ تَلْبَسِ الْقُفَّازَيْنِ‏.‏ وَقَالَ مَالِكٌ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ لاَ تَتَنَقَّبِ الْمُحْرِمَةُ‏.‏ وَتَابَعَهُ لَيْثُ بْنُ أَبِي سُلَيْمٍ‏.‏\hadithno{1838}\hadithtrans{Narrated `Abdullah bin `Umar:A person stood up and asked, "O Allah's: Apostle! What clothes may be worn in the state of Ihram?" The Prophet (ﷺ) replied, "Do not wear a shirt or trousers, or any headgear (e.g. a turban), or a hooded cloak; but if somebody has no shoes he can wear leather stockings provided they are cut short off the ankles, and also, do not wear anything perfumed with Wars or saffron, and the Muhrima (a woman in the state of Ihram) should not cover her face, or wear gloves}}
\hadithdefcmd{bukhari}{1839}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الْحَكَمِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ وَقَصَتْ بِرَجُلٍ مُحْرِمٍ نَاقَتُهُ، فَقَتَلَتْهُ، فَأُتِيَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ اغْسِلُوهُ، وَكَفِّنُوهُ، وَلاَ تُغَطُّوا رَأْسَهُ، وَلاَ تُقَرِّبُوهُ طِيبًا، فَإِنَّهُ يُبْعَثُ يُهِلُّ ‏"‏‏.‏\hadithno{1839}\hadithtrans{Narrated Ibn `Abbas:A man was crushed to death by his she-camel and was brought to Allah's Messenger (ﷺ) who said, "Give him a bath and shroud him, but do not cover his head, and do not bring any perfume near to him, as he will be resurrected reciting Talbiya}}
\hadithdefcmd{bukhari}{1840}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، أَنَّ عَبْدَ اللَّهِ بْنَ الْعَبَّاسِ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، اخْتَلَفَا بِالأَبْوَاءِ، فَقَالَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ يَغْسِلُ الْمُحْرِمُ رَأْسَهُ‏.‏ وَقَالَ الْمِسْوَرُ لاَ يَغْسِلُ الْمُحْرِمُ رَأْسَهُ‏.‏ فَأَرْسَلَنِي عَبْدُ اللَّهِ بْنُ الْعَبَّاسِ إِلَى أَبِي أَيُّوبَ الأَنْصَارِيِّ، فَوَجَدْتُهُ يَغْتَسِلُ بَيْنَ الْقَرْنَيْنِ، وَهُوَ يُسْتَرُ بِثَوْبٍ، فَسَلَّمْتُ عَلَيْهِ فَقَالَ مَنْ هَذَا فَقُلْتُ أَنَا عَبْدُ اللَّهِ بْنُ حُنَيْنٍ، أَرْسَلَنِي إِلَيْكَ عَبْدُ اللَّهِ بْنُ الْعَبَّاسِ، أَسْأَلُكَ كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْسِلُ رَأْسَهُ، وَهُوَ مُحْرِمٌ، فَوَضَعَ أَبُو أَيُّوبَ يَدَهُ عَلَى الثَّوْبِ، فَطَأْطَأَهُ حَتَّى بَدَا لِي رَأْسُهُ ثُمَّ قَالَ لإِنْسَانٍ يَصُبُّ عَلَيْهِ اصْبُبْ‏.‏ فَصَبَّ عَلَى رَأْسِهِ، ثُمَّ حَرَّكَ رَأْسَهُ بِيَدَيْهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ وَقَالَ هَكَذَا رَأَيْتُهُ صلى الله عليه وسلم يَفْعَلُ‏.‏\hadithno{1840}\hadithtrans{Narrated `Abdullah bin Hunain:`Abdullah bin Al-Abbas and Al-Miswar bin Makhrama differed at Al-Abwa'; Ibn `Abbas said that a Muhrim could wash his head; while Al-Miswar maintained that he should not do so. `Abdullah bin `Abbas sent me to Abu Aiyub Al-Ansari and I found him bathing between the two wooden posts (of the well) and was screened with a sheet of cloth. I greeted him and he asked who I was. I replied, "I am `Abdullah bin Hunain and I have been sent to you by Ibn `Abbas to ask you how Allah's Messenger (ﷺ) used to wash his head while in the state of Ihram." Abu Aiyub Al-Ansari caught hold of the sheet of cloth and lowered it till his head appeared before me, and then told somebody to pour water on his head. He poured water on his head, and he (Abu Aiyub) rubbed his head with his hands by bringing them from back to front and from front to back and said, "I saw the Prophet (ﷺ) doing like this}}
\hadithdefcmd{bukhari}{1841}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، سَمِعْتُ جَابِرَ بْنَ زَيْدٍ، سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ بِعَرَفَاتٍ ‏ "‏ مَنْ لَمْ يَجِدِ النَّعْلَيْنِ فَلْيَلْبَسِ الْخُفَّيْنِ، وَمَنْ لَمْ يَجِدْ إِزَارًا فَلْيَلْبَسْ سَرَاوِيلَ ‏"‏‏.‏ لِلْمُحْرِمِ‏.‏\hadithno{1841}\hadithtrans{Narrated Ibn `Abbas:I heard the Prophet (ﷺ) delivering a sermon at `Arafat saying, "If a Muhrim does not find slippers, he could wear Khuffs (socks made from thick fabric or leather, but he has to cut short the Khuffs below the ankles), and if he does not find an Izar (a waist sheet for wrapping the lower half of the body) he could wear trousers}}
\hadithdefcmd{bukhari}{1842}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا يَلْبَسُ الْمُحْرِمُ مِنَ الثِّيَابِ فَقَالَ ‏ "‏ لاَ يَلْبَسِ الْقَمِيصَ، وَلاَ الْعَمَائِمَ، وَلاَ السَّرَاوِيلاَتِ، وَلاَ الْبُرْنُسَ، وَلاَ ثَوْبًا مَسَّهُ زَعْفَرَانٌ وَلاَ وَرْسٌ، وَإِنْ لَمْ يَجِدْ نَعْلَيْنِ فَلْيَلْبَسِ الْخُفَّيْنِ، وَلْيَقْطَعْهُمَا حَتَّى يَكُونَا أَسْفَلَ مِنَ الْكَعْبَيْنِ ‏"‏‏.‏\hadithno{1842}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) was asked what sort of clothes a Muhrim should wear. He replied, "He should not wear a shirt, turbans, trousers, a hooded cloak, or a dress perfumed with saffron or Wars; and if slippers are not available he can wear Khuffs (socks made from thick fabric or leather) but he should cut them so that they reach below the ankles}}
\hadithdefcmd{bukhari}{1843}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ خَطَبَنَا النَّبِيُّ صلى الله عليه وسلم بِعَرَفَاتٍ فَقَالَ ‏ "‏ مَنْ لَمْ يَجِدِ الإِزَارَ فَلْيَلْبَسِ السَّرَاوِيلَ، وَمَنْ لَمْ يَجِدِ النَّعْلَيْنِ فَلْيَلْبَسِ الْخُفَّيْنِ ‏"‏‏.‏\hadithno{1843}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) delivered a sermon at `Arafat and said, "Whoever does not get an Izar can wear trousers, and whoever cannot get a pair of shoes can wear Khuffs (socks made from thick fabric or leather)}}
\hadithdefcmd{bukhari}{1844}{حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ اعْتَمَرَ النَّبِيُّ صلى الله عليه وسلم فِي ذِي الْقَعْدَةِ، فَأَبَى أَهْلُ مَكَّةَ أَنْ يَدَعُوهُ يَدْخُلُ مَكَّةَ، حَتَّى قَاضَاهُمْ لاَ يُدْخِلُ مَكَّةَ سِلاَحًا إِلاَّ فِي الْقِرَابِ‏.‏\hadithno{1844}\hadithtrans{Narrated Al-Bara:The Prophet (ﷺ) assumed Ihram for Umra in the month of Dhul-Qa'da but the (pagan) people of Mecca refused to admit him into Mecca till he agreed on the condition that he would not bring into Mecca any arms but sheathed}}
\hadithdefcmd{bukhari}{1845}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم وَقَّتَ لأَهْلِ الْمَدِينَةِ ذَا الْحُلَيْفَةِ، وَلأَهْلِ نَجْدٍ قَرْنَ الْمَنَازِلِ، وَلأَهْلِ الْيَمَنِ يَلَمْلَمَ، هُنَّ لَهُنَّ وَلِكُلِّ آتٍ أَتَى عَلَيْهِنَّ مِنْ غَيْرِهِمْ مِمَّنْ أَرَادَ الْحَجَّ وَالْعُمْرَةَ، فَمَنْ كَانَ دُونَ ذَلِكَ فَمِنْ حَيْثُ أَنْشَأَ، حَتَّى أَهْلُ مَكَّةَ مِنْ مَكَّةَ‏.‏\hadithno{1845}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) fixed Dhul-Hulaifa as the Miqat (the place for assuming Ihram) for the people of Medina, and Qaran-al-Manazil for the people of Najd, and Yalamlam for the people of Yemen. These Mawaqit are for those people and also for those who come through these Mawaqit (from places other than the above-mentioned) with the intention of (performing) Hajj and Umra. And those living inside these Mawaqit can assume Ihram from the place where they start; even the people of Mecca can assume Ihram from Mecca}}
\hadithdefcmd{bukhari}{1846}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَامَ الْفَتْحِ، وَعَلَى رَأْسِهِ الْمِغْفَرُ، فَلَمَّا نَزَعَهُ جَاءَ رَجُلٌ، فَقَالَ إِنَّ ابْنَ خَطَلٍ مُتَعَلِّقٌ بِأَسْتَارِ الْكَعْبَةِ‏.‏ فَقَالَ ‏ "‏ اقْتُلُوهُ ‏"‏‏.‏\hadithno{1846}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) entered Mecca in the year of its Conquest wearing an Arabian helmet on his head and when the Prophet (ﷺ) took it off, a person came and said, "Ibn Khatal is holding the covering of the Ka`ba (taking refuge in the Ka`ba)." The Prophet (ﷺ) said, "Kill him}}
\hadithdefcmd{bukhari}{1847}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا عَطَاءٌ، قَالَ حَدَّثَنِي صَفْوَانُ بْنُ يَعْلَى، عَنْ أَبِيهِ، قَالَ كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَتَاهُ رَجُلٌ عَلَيْهِ جُبَّةٌ فِيهِ أَثَرُ صُفْرَةٍ أَوْ نَحْوُهُ، وَكَانَ عُمَرُ يَقُولُ لِي تُحِبُّ إِذَا نَزَلَ عَلَيْهِ الْوَحْىُ أَنْ تَرَاهُ فَنَزَلَ عَلَيْهِ ثُمَّ سُرِّيَ عَنْهُ فَقَالَ ‏ "‏ اصْنَعْ فِي عُمْرَتِكَ مَا تَصْنَعُ فِي حَجِّكَ ‏"‏‏.‏\hadithno{1847}\hadithtrans{Narrated Ya'li:While I was with Allah's Messenger (ﷺ) there came to him a man wearing a cloak having a trace of yellowish perfume or a similar thing on it. `Umar used to say to me, "Would you like to see the Prophet (ﷺ) at the time when he is inspired divinely?" So, it happened that he was inspired (then) and when the inspiration was over the Prophet (ﷺ) said (to that man), "Do in your `Umra the same as you do in your Hajj}}
\hadithdefcmd{bukhari}{1848}{وَعَضَّ رَجُلٌ يَدَ رَجُلٍ ـ يَعْنِي فَانْتَزَعَ ثَنِيَّتَهُ ـ فَأَبْطَلَهُ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{1848}\hadithtrans{A man bit the hand of another man but in that process the latter broke one incisor tooth of the former, and the Prophet (ﷺ) forgave the latter}}
\hadithdefcmd{bukhari}{1849}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ بَيْنَا رَجُلٌ وَاقِفٌ مَعَ النَّبِيِّ صلى الله عليه وسلم بِعَرَفَةَ إِذْ وَقَعَ عَنْ رَاحِلَتِهِ، فَوَقَصَتْهُ ـ أَوْ قَالَ فَأَقْعَصَتْهُ ـ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ، وَكَفِّنُوهُ فِي ثَوْبَيْنِ ـ أَوْ قَالَ ثَوْبَيْهِ ـ وَلاَ تُحَنِّطُوهُ، وَلاَ تُخَمِّرُوا رَأْسَهُ، فَإِنَّ اللَّهَ يَبْعَثُهُ يَوْمَ الْقِيَامَةِ يُلَبِّي ‏"‏‏.‏\hadithno{1849}\hadithtrans{Narrated Ibn `Abbas:While a man was standing with the Prophet (ﷺ) at `Arafat, he fell from his Mount and his neck was crushed by it. The Prophet (ﷺ) said, "Wash the deceased with water and Sidr and shroud him in two pieces of cloth, and neither perfume him nor cover his head, for Allah will resurrect him on the Day of Resurrection and he will be reciting Talbiya}}
\hadithdefcmd{bukhari}{1850}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ بَيْنَا رَجُلٌ وَاقِفٌ مَعَ النَّبِيِّ صلى الله عليه وسلم بِعَرَفَةَ إِذْ وَقَعَ عَنْ رَاحِلَتِهِ فَوَقَصَتْهُ ـ أَوْ قَالَ فَأَوْقَصَتْهُ ـ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ، وَكَفِّنُوهُ فِي ثَوْبَيْنِ، وَلاَ تَمَسُّوهُ طِيبًا، وَلاَ تُخَمِّرُوا رَأْسَهُ، وَلاَ تُحَنِّطُوهُ، فَإِنَّ اللَّهَ يَبْعَثُهُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏‏.‏\hadithno{1850}\hadithtrans{Narrated Ibn `Abbas:While a man was standing with the Prophet (ﷺ) at `Arafat, he fell from his Mount and his neck was crushed by it. The Prophet (ﷺ) said, "Wash the deceased with water and Sidr and shroud him in two pieces of cloth, and neither perfume him nor cover his head, for Allah will resurrect him on the Day of Resurrection and he will be reciting Talbiya}}
\hadithdefcmd{bukhari}{1851}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَجُلاً، كَانَ مَعَ النَّبِيِّ صلى الله عليه وسلم فَوَقَصَتْهُ نَاقَتُهُ، وَهُوَ مُحْرِمٌ، فَمَاتَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ، وَكَفِّنُوهُ فِي ثَوْبَيْهِ، وَلاَ تَمَسُّوهُ بِطِيبٍ، وَلاَ تُخَمِّرُوا رَأْسَهُ، فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا ‏"‏‏.‏\hadithno{1851}\hadithtrans{Narrated Ibn `Abbas:A man was in the company of the Prophet (ﷺ) and his she-camel crushed his neck while he was in a state of Ihram and he died Allah's Messenger (ﷺ) said, "Wash him with water and Sidr and shroud him in his two garments; neither perfume him nor cover his head, for he will be resurrected on the Day of Resurrection, reciting Talbiya}}
\hadithdefcmd{bukhari}{1852}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ امْرَأَةً، مِنْ جُهَيْنَةَ جَاءَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ إِنَّ أُمِّي نَذَرَتْ أَنْ تَحُجَّ، فَلَمْ تَحُجَّ حَتَّى مَاتَتْ أَفَأَحُجُّ عَنْهَا قَالَ ‏ "‏ نَعَمْ‏.‏ حُجِّي عَنْهَا، أَرَأَيْتِ لَوْ كَانَ عَلَى أُمِّكِ دَيْنٌ أَكُنْتِ قَاضِيَةً اقْضُوا اللَّهَ، فَاللَّهُ أَحَقُّ بِالْوَفَاءِ ‏"‏‏.‏\hadithno{1852}\hadithtrans{Narrated Ibn `Abbas:A woman from the tribe of Juhaina came to the Prophet (ﷺ) and said, "My mother had vowed to perform Hajj but she died before performing it. May I perform Hajj on my mother's behalf?" The Prophet (ﷺ) replied, "Perform Hajj on her behalf. Had there been a debt on your mother, would you have paid it or not? So, pay Allah's debt as He has more right to be paid}}
\hadithdefcmd{bukhari}{1853}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ ـ رضى الله عنهم ـ أَنَّ امْرَأَةً، ح‏.‏\hadithno{1853}\hadithtrans{Narrated Ibn `Abbas:A woman from the tribe of Khath'am came in the year (of ,Hajjat-al-Wada` of the Prophet (ﷺ) ) and said, "O Allah's Messenger (ﷺ)! My father has come under Allah's obligation of performing Hajj but he is a very old man and cannot sit properly on his Mount. Will the obligation be fulfilled if I perform Hajj on his behalf?" The Prophet (ﷺ) replied in the affirmative}}
\hadithdefcmd{bukhari}{1854}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ جَاءَتِ امْرَأَةٌ مِنْ خَثْعَمَ، عَامَ حَجَّةِ الْوَدَاعِ، قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ عَلَى عِبَادِهِ فِي الْحَجِّ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا، لاَ يَسْتَطِيعُ أَنْ يَسْتَوِيَ عَلَى الرَّاحِلَةِ فَهَلْ يَقْضِي عَنْهُ أَنْ أَحُجَّ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏\hadithno{1854}\hadithtrans{Narrated `Abdullah bin `Abbas:Al-Fadl was riding behind the Prophet (ﷺ) and a woman from the tribe of Khath'am came up. Al-Fadl started looking at her and she looked at him. The Prophet (ﷺ) turned Al-Fadl's face to the other side. She said, "My father has come under Allah's obligation of performing Hajj but he is a very old man and cannot sit properly on his Mount. Shall I perform Hajj on his behalf? The Prophet (ﷺ) replied in the affirmative. That happened during Hajjat-al-Wada` of the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{1855}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ الْفَضْلُ رَدِيفَ النَّبِيِّ صلى الله عليه وسلم فَجَاءَتِ امْرَأَةٌ مِنْ خَثْعَمٍ، فَجَعَلَ الْفَضْلُ يَنْظُرُ إِلَيْهَا، وَتَنْظُرُ إِلَيْهِ فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يَصْرِفُ وَجْهَ الْفَضْلِ إِلَى الشِّقِّ الآخَرِ، فَقَالَتْ إِنَّ فَرِيضَةَ اللَّهِ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا، لاَ يَثْبُتُ عَلَى الرَّاحِلَةِ، أَفَأَحُجُّ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏ وَذَلِكَ فِي حَجَّةِ الْوَدَاعِ‏.‏\hadithno{1855}\hadithtrans{Narrated 'Abdullah bin 'Abbas (ra):Al Fadl was riding behind the Prophet (ﷺ) and a woman from the tribe of Khath'am came up. Al Fadl started looking at her and she looked at him. The Prophet (ﷺ) turned Al-Fadl's face to the other side. She said, "My father has come under Allah's obligation of performing Hajj but he is very old man and cannot sit properly on his Rahila (mount). Shall I perform Hajj on his behalf?" The Prophet (ﷺ) replied in the affirmative. That happened during Hajjat-ul-Wada' of the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{1856}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ بَعَثَنِي ـ أَوْ قَدَّمَنِي ـ النَّبِيُّ صلى الله عليه وسلم فِي الثَّقَلِ مِنْ جَمْعٍ بِلَيْلٍ‏.‏\hadithno{1856}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) sent me (to Mina) with the luggage from Jam' (i.e. Al-Muzdalifa) at night}}
\hadithdefcmd{bukhari}{1857}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ، عَنْ عَمِّهِ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ أَقْبَلْتُ وَقَدْ نَاهَزْتُ الْحُلُمَ، أَسِيرُ عَلَى أَتَانٍ لِي، وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يُصَلِّي بِمِنًى، حَتَّى سِرْتُ بَيْنَ يَدَىْ بَعْضِ الصَّفِّ الأَوَّلِ، ثُمَّ نَزَلْتُ عَنْهَا فَرَتَعَتْ، فَصَفَفْتُ مَعَ النَّاسِ وَرَاءَ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ وَقَالَ يُونُسُ عَنِ ابْنِ شِهَابٍ بِمِنًى فِي حَجَّةِ الْوَدَاعِ‏.‏\hadithno{1857}\hadithtrans{Narrated `Abdullah bin `Abbas:I came riding on my she-ass and had (just) then attained the age of puberty. Allah's Messenger (ﷺ) was praying at Mina. I passed in front of a part of the first row and then dismounted from it, and the animal started grazing. I aligned with the people behind Allah's Messenger (ﷺ) (The sub-narrator added that happened in Mina during the Prophet's Hajjat-al-Wada)}}
\hadithdefcmd{bukhari}{1858}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ يُونُسَ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ مُحَمَّدِ بْنِ يُوسُفَ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ حُجَّ بِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا ابْنُ سَبْعِ سِنِينَ‏.‏\hadithno{1858}\hadithtrans{Narrated As-Sa'ib bin Yazid:(While in the company of my parents) I was made to perform Hajj with Allah's Messenger (ﷺ) and I was a seven-year-old boy then. (Fath-ul-Bari, p.443, Vol)}}
\hadithdefcmd{bukhari}{1859}{حَدَّثَنَا عَمْرُو بْنُ زُرَارَةَ، أَخْبَرَنَا الْقَاسِمُ بْنُ مَالِكٍ، عَنِ الْجُعَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، يَقُولُ لِلسَّائِبِ بْنِ يَزِيدَ، وَكَانَ قَدْ حُجَّ بِهِ فِي ثَقَلِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1859}\hadithtrans{Narrated Al-Ju'aid bin `Abdur-Rahman:I heard `Umar bin `Abdul `Aziz telling about As-Sa'ib bin Yazid that he had performed Hajj (while carried) with the belongings of the Prophet}}
\hadithdefcmd{bukhari}{1860}{وَقَالَ لِي أَحْمَدُ بْنُ مُحَمَّدٍ حَدَّثَنَا إِبْرَاهِيمُ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَذِنَ عُمَرُ ـ رضى الله عنه ـ لأَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم فِي آخِرِ حَجَّةٍ حَجَّهَا، فَبَعَثَ مَعَهُنَّ عُثْمَانَ بْنَ عَفَّانَ وَعَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ‏.‏\hadithno{1860}\hadithtrans{Narrated Ibrahim's grand-father that 'Umar(ra) in his last Hajj allowed the wives of the Prophet(ﷺ)to perform Hajj and he sent with them 'Uthman bin 'Affan(ra) and 'Abdur-Rahman bin 'Auf(ra) as escorts}}
\hadithdefcmd{bukhari}{1861}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي عَمْرَةَ، قَالَ حَدَّثَتْنَا عَائِشَةُ بِنْتُ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ ـ رضى الله عنها ـ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ أَلاَ نَغْزُوا وَنُجَاهِدُ مَعَكُمْ فَقَالَ ‏ "‏ لَكُنَّ أَحْسَنُ الْجِهَادِ وَأَجْمَلُهُ الْحَجُّ، حَجٌّ مَبْرُورٌ ‏"‏‏.‏ فَقَالَتْ عَائِشَةُ فَلاَ أَدَعُ الْحَجَّ بَعْدَ إِذْ سَمِعْتُ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{1861}\hadithtrans{Narrated Aisha (mother of the faithful believers):I said, "O Allah's Messenger (ﷺ)! Shouldn't we participate in Holy battles and Jihad along with you?" He replied, "The best and the most superior Jihad (for women) is Hajj which is accepted by Allah." `Aisha added: Ever since I heard that from Allah's Messenger (ﷺ) I have determined not to miss Hajj}}
\hadithdefcmd{bukhari}{1862}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرٍو، عَنْ أَبِي مَعْبَدٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ تُسَافِرِ الْمَرْأَةُ إِلاَّ مَعَ ذِي مَحْرَمٍ، وَلاَ يَدْخُلُ عَلَيْهَا رَجُلٌ إِلاَّ وَمَعَهَا مَحْرَمٌ ‏"‏‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ إِنِّي أُرِيدُ أَنْ أَخْرُجَ فِي جَيْشِ كَذَا وَكَذَا، وَامْرَأَتِي تُرِيدُ الْحَجَّ‏.‏ فَقَالَ ‏"‏ اخْرُجْ مَعَهَا ‏"‏‏.‏\hadithno{1862}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "A woman should not travel except with a Dhu-Mahram (her husband or a man with whom that woman cannot marry at all according to the Islamic Jurisprudence), and no man may visit her except in the presence of a Dhu-Mahram." A man got up and said, "O Allah's Messenger (ﷺ)! I intend to go to such and such an army and my wife wants to perform Hajj." The Prophet (ﷺ) said (to him), "Go along with her (to Hajj)}}
\hadithdefcmd{bukhari}{1863}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، أَخْبَرَنَا حَبِيبٌ الْمُعَلِّمُ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا رَجَعَ النَّبِيُّ صلى الله عليه وسلم مِنْ حَجَّتِهِ قَالَ لأُمِّ سِنَانٍ الأَنْصَارِيَّةِ ‏"‏ مَا مَنَعَكِ مِنَ الْحَجِّ ‏"‏‏.‏ قَالَتْ أَبُو فُلاَنٍ ـ تَعْنِي زَوْجَهَا ـ كَانَ لَهُ نَاضِحَانِ، حَجَّ عَلَى أَحَدِهِمَا، وَالآخَرُ يَسْقِي أَرْضًا لَنَا‏.‏ قَالَ ‏"‏ فَإِنَّ عُمْرَةً فِي رَمَضَانَ تَقْضِي حَجَّةً مَعِي ‏"‏‏.‏ رَوَاهُ ابْنُ جُرَيْجٍ عَنْ عَطَاءٍ سَمِعْتُ ابْنَ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1863}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) returned after performing his Hajj, he asked Um Sinan Al-Ansari, "What did forbid you to perform Hajj?" She replied, "Father of so-and-so (i.e. her husband) had two camels and he performed Hajj on one of them, and the second is used for the irrigation of our land." The Prophet (ﷺ) said (to her), "Perform `Umra in the month of Ramadan, (as it is equivalent to Hajj or Hajj with me (in reward)}}
\hadithdefcmd{bukhari}{1864}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ قَزَعَةَ، مَوْلَى زِيَادٍ قَالَ سَمِعْتُ أَبَا سَعِيدٍ ـ وَقَدْ غَزَا مَعَ النَّبِيِّ صلى الله عليه وسلم ثِنْتَىْ عَشْرَةَ ـ غَزْوَةً ـ قَالَ أَرْبَعٌ سَمِعْتُهُنَّ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَوْ قَالَ يُحَدِّثُهُنَّ عَنِ النَّبِيِّ صلى الله عليه وسلم ـ فَأَعْجَبْنَنِي وَآنَقْنَنِي ‏ "‏ أَنْ لاَ تُسَافِرَ امْرَأَةٌ مَسِيرَةَ يَوْمَيْنِ لَيْسَ مَعَهَا زَوْجُهَا أَوْ ذُو مَحْرَمٍ، وَلاَ صَوْمَ يَوْمَيْنِ الْفِطْرِ وَالأَضْحَى، وَلاَ صَلاَةَ بَعْدَ صَلاَتَيْنِ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ، وَبَعْدَ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ، وَلاَ تُشَدُّ الرِّحَالُ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ مَسْجِدِ الْحَرَامِ، وَمَسْجِدِي، وَمَسْجِدِ الأَقْصَى ‏"‏‏.‏\hadithno{1864}\hadithtrans{Narrated Qaza'a the slave of Ziyad:Abu Sa`id who participated in twelve Ghazawat with the Prophet (ﷺ) said, "I heard four things from Allah's Messenger (ﷺ) (or I narrate them from the Prophet (ﷺ) ) which won my admiration and appreciation. They are: -1. "No lady should travel without her husband or without a Dhu-Mahram for a two-days' journey. -2. No fasting is permissible on two days of `Id-ul-Fitr, and `Id-al-Adha. -3. No prayer (may be offered) after two prayers: after the `Asr prayer till the sun set and after the morning prayer till the sun rises. -4. Not to travel (for visiting) except for three mosques: Masjid-al-Haram (in Mecca), my Mosque (in Medina), and Masjid-al-Aqsa (in Jerusalem)}}
\hadithdefcmd{bukhari}{1865}{حَدَّثَنَا ابْنُ سَلاَمٍ، أَخْبَرَنَا الْفَزَارِيُّ، عَنْ حُمَيْدٍ الطَّوِيلِ، قَالَ حَدَّثَنِي ثَابِتٌ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى شَيْخًا يُهَادَى بَيْنَ ابْنَيْهِ قَالَ ‏"‏ مَا بَالُ هَذَا ‏"‏‏.‏ قَالُوا نَذَرَ أَنْ يَمْشِيَ‏.‏ قَالَ ‏"‏ إِنَّ اللَّهَ عَنْ تَعْذِيبِ هَذَا نَفْسَهُ لَغَنِيٌّ ‏"‏‏.‏ وَأَمَرَهُ أَنْ يَرْكَبَ‏.‏\hadithno{1865}\hadithtrans{Narrated Anas:The Prophet (ﷺ) saw an old man walking, supported by his two sons, and asked about him. The people informed him that he had vowed to go on foot (to the Ka`ba). He said, "Allah is not in need of this old man's torturing himself," and ordered him to ride}}
\hadithdefcmd{bukhari}{1866}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، أَنَّ يَزِيدَ بْنَ أَبِي حَبِيبٍ، أَخْبَرَهُ أَنَّ أَبَا الْخَيْرِ حَدَّثَهُ عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ نَذَرَتْ أُخْتِي أَنْ تَمْشِيَ، إِلَى بَيْتِ اللَّهِ، وَأَمَرَتْنِي أَنْ أَسْتَفْتِيَ لَهَا النَّبِيَّ صلى الله عليه وسلم فَاسْتَفْتَيْتُهُ، فَقَالَ عَلَيْهِ السَّلاَمُ ‏ "‏ لِتَمْشِ وَلْتَرْكَبْ ‏"‏‏.‏ قَالَ وَكَانَ أَبُو الْخَيْرِ لاَ يُفَارِقُ عُقْبَةَ‏.‏ قَالَ أَبُو عَبْد اللَّهِ حَدَّثَنَا أَبُو عَاصِمٍ عَنْ ابْنِ جُرَيْجٍ عَنْ يَحْيَى بْنِ أَيُّوبَ عَنْ يَزِيدَ عَنْ أَبِي الْخَيْرِ عَنْ عُقْبَةَ فَذَكَرَ الْحَدِيثَ\hadithno{1866}\hadithtrans{Narrated `Uqba bin 'Amir:My sister vowed to go on foot to the Ka`ba, and she asked me to take the verdict of the Prophet (ﷺ) about it. So, I did and the Prophet (ﷺ) said, "She should walk and also should ride." Narrated Abul-Khair from `Uqba as above.:}}
